==> nordugrid-arc_5.0.5.orig.tar.gz: nordugrid-arc-5.0.5/src/hed/acc/ARC1/SubmitterPluginARC1.h <==
// -*- indent-tabs-mode: nil -*-

#ifndef __ARC_SUBMITTERPLUGINARC1_H__
#define __ARC_SUBMITTERPLUGINARC1_H__

#include <arc/compute/SubmitterPlugin.h>
#include <arc/XMLNode.h>
#include <arc/URL.h>
#include <arc/loader/Loader.h>
#include <arc/communication/ClientInterface.h>

#include "AREXClient.h"

namespace Arc {

  class SubmissionStatus;

  class SubmitterPluginARC1 : public SubmitterPlugin {
  public:
    SubmitterPluginARC1(const UserConfig& usercfg, PluginArgument* parg) : SubmitterPlugin(usercfg, parg), clients(this->usercfg) { supportedInterfaces.push_back("org.ogf.bes"); }
    ~SubmitterPluginARC1() { /*deleteAllClients();*/ }

    static Plugin* Instance(PluginArgument *arg) {
      SubmitterPluginArgument *subarg = dynamic_cast<SubmitterPluginArgument*>(arg);
      return subarg ? new SubmitterPluginARC1(*subarg, arg) : NULL;
    }

    bool isEndpointNotSupported(const std::string& endpoint) const;

    virtual SubmissionStatus Submit(const std::list<JobDescription>& jobdescs, const std::string& endpoint, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
    virtual SubmissionStatus Submit(const std::list<JobDescription>& jobdescs, const ExecutionTarget& et, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
    virtual bool Migrate(const std::string& jobid, const JobDescription& jobdesc,
                         const ExecutionTarget& et, bool forcemigration,
                         Job& job);

  private:
    // Centralized AREXClient handling
    AREXClients clients;

    static Logger logger;
  };

} // namespace Arc

#endif // __ARC_SUBMITTERPLUGINARC1_H__

==> nordugrid-arc_5.3.0~rc1.orig.tar.gz: nordugrid-arc-5.3.0rc1/src/hed/acc/ARC1/SubmitterPluginARC1.h <==
// -*- indent-tabs-mode: nil -*-

#ifndef __ARC_SUBMITTERPLUGINARC1_H__
#define __ARC_SUBMITTERPLUGINARC1_H__

#include <arc/compute/SubmitterPlugin.h>
#include <arc/XMLNode.h>
#include <arc/URL.h>
#include <arc/loader/Loader.h>
#include <arc/communication/ClientInterface.h>

#include "AREXClient.h"

namespace Arc {

  class SubmissionStatus;

  class SubmitterPluginARC1 : public SubmitterPlugin {
  public:
    SubmitterPluginARC1(const UserConfig& usercfg, PluginArgument* parg) : SubmitterPlugin(usercfg, parg), clients(usercfg) { supportedInterfaces.push_back("org.ogf.bes"); }
    ~SubmitterPluginARC1() { /*deleteAllClients();*/ }

    static Plugin* Instance(PluginArgument *arg) {
      SubmitterPluginArgument *subarg = dynamic_cast<SubmitterPluginArgument*>(arg);
      return subarg ? new SubmitterPluginARC1(*subarg, arg) : NULL;
    }

    bool isEndpointNotSupported(const std::string& endpoint) const;

    virtual SubmissionStatus Submit(const std::list<JobDescription>& jobdescs, const std::string& endpoint, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
    virtual SubmissionStatus Submit(const std::list<JobDescription>& jobdescs, const ExecutionTarget& et, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
    virtual bool Migrate(const std::string& jobid, const JobDescription& jobdesc,
                         const ExecutionTarget& et, bool forcemigration,
                         Job& job);

  private:
    // Centralized AREXClient handling
    AREXClients clients;

    static Logger logger;
  };

} // namespace Arc

#endif // __ARC_SUBMITTERPLUGINARC1_H__
